<template>
  <a-modal :title='title' :width='600' :visible='visible' :maskClosable='false' :confirmLoading='confirmLoading'
           :okButtonProps='{ props: {disabled: disableSubmit} }' @ok='handleOk' @cancel='handleCancel' cancelText='关闭'>
    <a-spin :spinning='confirmLoading'>
      <a-form :form='form'>

        <a-row :gutter='12'>
          <a-col :span='24'>
            <a-form-item label='终端名称' :labelCol='labelCol' :wrapperCol='wrapperCol'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入终端名称' allow-clear
                       :maxLength='10' v-decorator="[ 'serverName', validatorRules.serverName]" />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item label='终端IP' :labelCol='labelCol' :wrapperCol='wrapperCol'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入终端IP' allow-clear
                       :maxLength='15' v-decorator="['serverAddress', validatorRules.serverAddress]" />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item label='端口' :labelCol='labelCol' :wrapperCol='wrapperCol'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入端口' allow-clear
                       :maxLength='6' v-decorator="[ 'serverPort', validatorRules.serverPort]" />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='备注'>
              <a-textarea :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入备注' allow-clear
                          v-decorator="['remark', validatorRules.remark]" />
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>
    <template slot='footer' v-if='disableSubmit == false'>
      <a-button :style="{ marginRight: '8px' }" @click='handleCancel'>关闭</a-button>
      <a-button @click='handleOk' type='primary'>确定</a-button>
    </template>
    <template slot='footer' v-if='disableSubmit == true'>
      <a-button :style="{ marginRight: '8px' }" @click='handleCancel'>关闭</a-button>
    </template>
  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { httpAction } from '@/api/manage'

export default {
  name: 'UnitModel',
  props: ['projectClassify'],
  data() {
    return {
      title: '',
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        serverName: {
          rules: [{
            required: true,
            message: '请输入终端名称'
          },
            {
              min: 0,
              max: 30,
              message: '长度不超过 30 个字符',
              trigger: 'blur'
            }
          ]
        },
        serverAddress: {
          rules: [{
            required: true,
            message: '请输入终端IP',
            min: 0,
            max: 30,
            trigger: 'blur'
          }
          ]
        },
        serverPort: {
          rules: [{
            required: true,
            message: '请输入端口'
          }]
        },
        decimalPlace: {
          rules: [{
            required: true,
            message: '请输入小数位'
          }
          ]
        },
        remark: {
          rules: [{
            min: 0,
            max: 100,
            message: '最长 100 个字符',
            trigger: 'blur'
          }]
        }
      },
      url: {
        add: '/serve/deploy/add',
        edit: '/serve/deploy/edit'
      },
      disableSubmit: false
    }
  },

  methods: {
    add() {
      this.edit({})
    },
    edit(record) {
      this.form.resetFields()
      this.model = Object.assign({}, record)
      this.visible = true
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model, 'serverAddress', 'serverName', 'serverPort', 'remark'))
      })

    },
    close() {
      this.$emit('close')
      this.visible = false
    },
    handleOk() {
      const that = this
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true
          let formData = Object.assign(this.model, values)
          let obj
          if (!this.model.id) {
            formData.projectClassifyId = this.projectClassify
            obj = httpAction(this.url.add, formData, 'post')
          } else {
            obj = httpAction(this.url.edit, formData, 'put')
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              this.$emit('ok', res.result)
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
            that.close()
          })
        }
      })
    },
    handleCancel() {
      this.close()
    }
  }
}
</script>

<style scoped>
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>
